@@ -1,7 +1,5 @@
 #' @describeIn plot Plots a two-dimensional confidence region for model
 #'   parameters.
-#' @srrstats {RE6.0} `plot` method is available for an `ConfregEL` object that
-#'   is returned by the `confreg()` method.
 setMethod("plot", "ConfregEL", function(x, ...) {
   args <- list(...)
   if (!exists("main", args)) {
@@ -30,10 +28,14 @@ setMethod("plot", "ConfregEL", function(x, ...) {
   text(x@estimates[1L], x@estimates[2L], expression(hat(theta)), pos = 4L)
 })
 
+#' @describeIn plot Plots empirical likelihood displacement values versus
+#'   observation index. `eld()` is called implicitly.
+setMethod("plot", "EL", function(x, ...) {
+  plot(eld(x), ...)
+})
+
 #' @describeIn plot Plots empirical likelihood displacement values versus
 #'   observation index.
-#' @srrstats {RE6.0} `plot` method is available for an `ELD` object that is
-#'   returned by the `eld()` method.
 setMethod("plot", "ELD", function(x, ...) {
   args <- list(...)
   if (!exists("xlab", args)) {
