@@ -81,7 +81,8 @@ EL::set_g_fn(const std::string method)
              {"poisson_log", g_poi_log},
              {"poisson_identity", g_poi_identity},
              {"poisson_sqrt", g_poi_sqrt},
-             {"quasipoisson_log", g_qpoi_log}}};
+             {"quasipoisson_log", g_qpoi_log},
+             {"quasipoisson_identity", g_qpoi_identity}}};
   return g_map[method];
 }
 
@@ -156,8 +157,9 @@ double EL::loglik() const
   }
 }
 
+
 /* CEL class (minimization)
- * Last updated: 07/04/22
+ * Last updated: 08/23/22
  */
 CEL::CEL(const std::string method,
          const Eigen::Ref<const Eigen::VectorXd> &par0,
@@ -178,12 +180,9 @@ CEL::CEL(const std::string method,
       gr_fn{CEL::set_gr_fn(method)}
 {
   /// initialization ///
-  // orthogonal projection matrix
-  const Eigen::MatrixXd proj =
-      Eigen::MatrixXd::Identity(lhs.cols(), lhs.cols()) -
-      lhs.transpose() * (lhs * lhs.transpose()).inverse() * lhs;
   // parameter (constraint imposed)
-  par = proj * par0 + lhs.transpose() * (lhs * lhs.transpose()).inverse() * rhs;
+  par = proj(lhs, par0) +
+        lhs.bdcSvd(Eigen::ComputeThinU | Eigen::ComputeThinV).solve(rhs);
   // estimating function
   Eigen::MatrixXd g = g_fn(x, par);
   // lambda
@@ -191,14 +190,14 @@ CEL::CEL(const std::string method,
   // function value (-logLR)
   nllr = PseudoLog::sum(Eigen::VectorXd::Ones(n) + g * l, wt);
   // function norm
-  // const double norm0 = (proj * gr_fn(l, g, x, par, wt, weighted)).norm();
+  // const double norm0 = proj(lhs, gr_fn(l, g, x, par, wt, weighted)).norm();
 
   /// minimization (projected gradient descent) ///
   while (!conv && iter != maxit && nllr <= th)
   {
     // update parameter
     Eigen::VectorXd par_tmp =
-        par - gamma * proj * gr_fn(l, g, x, par, wt, weighted);
+        par - gamma * proj(lhs, gr_fn(l, g, x, par, wt, weighted));
     // update estimating function
     Eigen::MatrixXd g_tmp = g_fn(x, par_tmp);
     // update lambda
@@ -214,18 +213,16 @@ CEL::CEL(const std::string method,
       gamma /= 2;
       if (gamma < DBL_EPSILON)
       {
-        // Rcpp::Rcout << "seffff" << "\n";
         break;
       }
       // propose new parameter
-      par_tmp = par - gamma * proj * gr_fn(l, g, x, par, wt, weighted);
+      par_tmp = par - gamma * proj(lhs, gr_fn(l, g, x, par, wt, weighted));
       // propose new lambda
       g_tmp = g_fn(x, par_tmp);
       l_tmp = EL(g_tmp, maxit_l, tol_l, th, wt).l;
       // propose new function value
       nllr = PseudoLog::sum(Eigen::VectorXd::Ones(n) + g_tmp * l_tmp, wt);
     }
-
     if (nllr >= f0)
     {
       nllr = f0;
@@ -235,13 +232,12 @@ CEL::CEL(const std::string method,
     else if (std::isnan(nllr))
     {
       // return initial values
-      par = proj * par0 + lhs.transpose() * (lhs * lhs.transpose()).inverse() *
-                              rhs;
+      par = proj(lhs, par0) +
+            lhs.bdcSvd(Eigen::ComputeThinU | Eigen::ComputeThinV).solve(rhs);
       Eigen::MatrixXd g = g_fn(x, par);
       l = EL(g, maxit_l, tol_l, th, wt).l;
       nllr = PseudoLog::sum(Eigen::VectorXd::Ones(n) + g * l, wt);
     }
-
     // update
     const double s = (par - par_tmp).norm();
     const double d = par.norm();
@@ -249,7 +245,7 @@ CEL::CEL(const std::string method,
     l = std::move(l_tmp);
     g = std::move(g_tmp);
     // convergence check
-    if ((proj * gr_fn(l, g, x, par, wt, weighted)).norm() < tol ||
+    if (proj(lhs, gr_fn(l, g, x, par, wt, weighted)).norm() < tol ||
         s < tol * d + tol * tol)
     {
       conv = true;
@@ -277,7 +273,8 @@ CEL::set_g_fn(const std::string method)
              {"poisson_log", g_poi_log},
              {"poisson_identity", g_poi_identity},
              {"poisson_sqrt", g_poi_sqrt},
-             {"quasipoisson_log", g_qpoi_log}}};
+             {"quasipoisson_log", g_qpoi_log},
+             {"quasipoisson_identity", g_qpoi_identity}}};
   return g_map[method];
 }
 
@@ -309,7 +306,8 @@ CEL::set_gr_fn(const std::string method)
            {"poisson_log", gr_nloglr_poi_log},
            {"poisson_identity", gr_nloglr_poi_identity},
            {"poisson_sqrt", gr_nloglr_poi_sqrt},
-           {"quasipoisson_log", gr_nloglr_qpoi_log}}};
+           {"quasipoisson_log", gr_nloglr_qpoi_log},
+           {"quasipoisson_identity", gr_nloglr_qpoi_identity}}};
   return gr_map[method];
 }
 
@@ -340,10 +338,7 @@ double CEL::loglik(const Eigen::Ref<const Eigen::ArrayXd> &wt) const
   }
 }
 
-/* PseudoLog class
- * Last updated: 04/07/22
- *
- */
+
 PseudoLog::PseudoLog(const Eigen::Ref<const Eigen::ArrayXd> &x,
                      const Eigen::Ref<const Eigen::ArrayXd> &w)
 {
