@@ -14,6 +14,9 @@ test_that("Bootstrap calibration for `elt()`.", {
   fit9 <- el_glm(wool ~ ., family = binomial("logit"), data = warpbreaks)
   fit10 <- el_glm(wool ~ ., family = binomial("probit"), data = warpbreaks)
   expect_s4_class(elt(fit, rhs = 65, calibrate = "boot"), "ELT")
+  expect_s4_class(elt(fit,
+    rhs = 65, calibrate = "boot", control = el_control(seed = 258)
+  ), "ELT")
   expect_s4_class(elt(fit2, rhs = coef(fit2), calibrate = "boot"), "ELT")
   expect_s4_class(elt(fit3, rhs = coef(fit3), calibrate = "boot"), "ELT")
   expect_s4_class(elt(fit4, rhs = coef(fit4), calibrate = "boot"), "ELT")
@@ -482,7 +485,7 @@ test_that("`el_glm()` (quasipoisson - identity).", {
   expect_s4_class(elmt(wfit, rhs = rhs, lhs = lhs), "ELMT")
 })
 
-test_that("`el_pairwise()` (deprecated).", {
+test_that("`el_pairwise()`. Deprecated.", {
   skip_on_cran()
   out1 <- suppressWarnings(el_pairwise(clo ~ trt | blk,
     data = clothianidin, B = 500
@@ -505,3 +508,20 @@ test_that("`el_pairwise()` (deprecated).", {
   ))
   expect_output(print(out3))
 })
+
+test_that("Invalid `formula`. Deprecated.", {
+  fit <- el_lm(mpg ~ 0, data = mtcars)
+  expect_error(suppressWarnings(logLik(fit)))
+})
+
+test_that(
+  "`logLik()` at the maximum empirical likelihood estimate. Deprecated.",
+  {
+    n <- nrow(airquality)
+    fit <- el_lm(Wind ~ Temp, data = airquality)
+    logLik <- suppressWarnings(logLik(fit, REML = TRUE))
+    expect_output(show(logLik))
+    expect_output(print(logLik))
+    expect_equal(getDataPart(logLik), -n * log(n))
+  }
+)
